@@ -76,7 +76,8 @@ mod_power <- function(n_groups, effect_sizes, sample_size, k, es_type, p = .05,
     mod_power_range_df <- data.frame(k_v = seq(from = n_groups, to = range_factor*k, by = n_groups),
                                  overall_effect = overall_effect,
                                  n_groups = n_groups,
-                                 n_v = sample_size/n_groups,
+                                 #n_v = sample_size/n_groups,
+                                 n_v = sample_size,
                                  c_alpha_b = c_alpha_b,
                                  c_alpha_w = c_alpha_w) %>% dplyr::mutate(variance = mapply(compute_variance, .data$n_v, .data$overall_effect, es_type))
 
